==> foundation-v2-peercoin-0.0.1.tgz: package/stratum/test/transactions.test.js <==
const Transactions = require('../main/transactions');
const config = require('../../configs/example');
const testdata = require('../../daemon/test/daemon.mock');

config.primary.address = 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb';
config.primary.recipients = [];

const auxiliaryConfig = {
  'enabled': false,
  'coin': {
    'header': 'fabe6d6d',
  }
};

const auxiliaryData = {
  'chainid': 1,
  'hash': '17a35a38e70cd01488e0d5ece6ded04a9bc8125865471d36b9d5c47a08a5907c',
};

const extraNonce = Buffer.from('f000000ff111111f', 'hex');

////////////////////////////////////////////////////////////////////////////////

describe('Test transactions functionality', () => {

  let configCopy, rpcDataCopy;
  beforeEach(() => {
    configCopy = JSON.parse(JSON.stringify(config));
    rpcDataCopy = JSON.parse(JSON.stringify(testdata.getBlockTemplate()));
  });

  test('Test main transaction builder [1]', () => {
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [2]', () => {
    rpcDataCopy.coinbasetxn = {};
    rpcDataCopy.coinbasetxn.data = '0500008085202';
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0500008025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [3]', () => {
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('0000000003803f1f1b010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac80b2e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [4]', () => {
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('0000000004008d380c010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac80b2e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac80b2e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [5]', () => {
    rpcDataCopy.coinbaseaux.flags = 'test';
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [6]', () => {
    delete rpcDataCopy.default_witness_commitment;
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000100f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac00000000', 'hex'));
  });

  test('Test main transaction builder [7]', () => {
    rpcDataCopy.auxData = auxiliaryData;
    configCopy.auxiliary = auxiliaryConfig;
    configCopy.auxiliary.enabled = true;
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, 48)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff3b5104', 'hex'));
    expect(transaction[0].slice(53, 57)).toStrictEqual(Buffer.from('fabe6d6d', 'hex'));
    expect(transaction[0].slice(57)).toStrictEqual(Buffer.from('17a35a38e70cd01488e0d5ece6ded04a9bc8125865471d36b9d5c47a08a5907c0100000000000000', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [8]', () => {
    configCopy.settings.testnet = true;
    configCopy.primary.address = 'n1T3Tg3hLEH58Tmzeqeu1SfycAga1p1W2p';
    const transaction = new Transactions(configCopy).handleGeneration(rpcDataCopy, extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a914daa52a00b0d89cedd9bea09ba947bff73f8112b488ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });
});

==> foundation-v2-peercoin-0.0.4.tgz: package/stratum/test/transactions.test.js <==
const Transactions = require('../main/transactions');
const config = require('../../configs/example');
const testdata = require('../../daemon/test/daemon.mock');

config.primary.address = 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb';
config.primary.recipients = [];

const auxiliaryConfig = {
  'enabled': false,
  'coin': {
    'header': 'fabe6d6d',
  }
};

const auxiliaryData = {
  'chainid': 1,
  'hash': '17a35a38e70cd01488e0d5ece6ded04a9bc8125865471d36b9d5c47a08a5907c',
};

const extraNonce = Buffer.from('f000000ff111111f', 'hex');

////////////////////////////////////////////////////////////////////////////////

describe('Test transactions functionality', () => {

  let configCopy, rpcDataCopy, rpcDataTransactionsCopy;
  beforeEach(() => {
    configCopy = JSON.parse(JSON.stringify(config));
    rpcDataCopy = JSON.parse(JSON.stringify(testdata.getBlockTemplate()));
    rpcDataTransactionsCopy = JSON.parse(JSON.stringify(testdata.getBlockTemplateWithTransactions()));
  });

  test('Test main transaction builder [1]', () => {
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [2]', () => {
    rpcDataCopy.coinbasetxn = {};
    rpcDataCopy.coinbasetxn.data = '0500008085202';
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0500008025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [3]', () => {
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('0000000003803f1f1b010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac80b2e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [4]', () => {
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('0000000004008d380c010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac80b2e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac80b2e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [5]', () => {
    rpcDataCopy.coinbaseaux.flags = 'test';
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [6]', () => {
    delete rpcDataCopy.default_witness_commitment;
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000100f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac00000000', 'hex'));
  });

  test('Test main transaction builder [7]', () => {
    rpcDataCopy.auxData = auxiliaryData;
    configCopy.auxiliary = auxiliaryConfig;
    configCopy.auxiliary.enabled = true;
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, 48)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff3b5104', 'hex'));
    expect(transaction[0].slice(53, 57)).toStrictEqual(Buffer.from('fabe6d6d', 'hex'));
    expect(transaction[0].slice(57)).toStrictEqual(Buffer.from('17a35a38e70cd01488e0d5ece6ded04a9bc8125865471d36b9d5c47a08a5907c0100000000000000', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder [8]', () => {
    configCopy.settings.testnet = true;
    configCopy.primary.address = 'n1T3Tg3hLEH58Tmzeqeu1SfycAga1p1W2p';
    const transaction = new Transactions(configCopy, rpcDataCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000200f2052a010000001976a914daa52a00b0d89cedd9bea09ba947bff73f8112b488ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [1]', () => {
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000021019062a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [2]', () => {
    rpcDataTransactionsCopy.coinbasetxn = {};
    rpcDataTransactionsCopy.coinbasetxn.data = '0500008085202';
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0500008025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000021019062a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [3]', () => {
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000039c641f1b010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac74b4e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [4]', () => {
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    configCopy.primary.recipients.push({ address: 'P9iJda86q6tWdHYsBXZGPGcxu5PYFGJDdb', percentage: 0.05 });
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('000000000428b0380c010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac74b4e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac74b4e60e000000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [5]', () => {
    rpcDataTransactionsCopy.coinbaseaux.flags = 'test';
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000021019062a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [6]', () => {
    delete rpcDataTransactionsCopy.default_witness_commitment;
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000011019062a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac00000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [7]', () => {
    rpcDataTransactionsCopy.auxData = auxiliaryData;
    configCopy.auxiliary = auxiliaryConfig;
    configCopy.auxiliary.enabled = true;
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, 48)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff3b5104', 'hex'));
    expect(transaction[0].slice(53, 57)).toStrictEqual(Buffer.from('fabe6d6d', 'hex'));
    expect(transaction[0].slice(57)).toStrictEqual(Buffer.from('17a35a38e70cd01488e0d5ece6ded04a9bc8125865471d36b9d5c47a08a5907c0100000000000000', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000021019062a010000001976a9140c51472d3baaba06de2b53c1d2414ebb2efcf94988ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });

  test('Test main transaction builder w/ transactions [8]', () => {
    configCopy.settings.testnet = true;
    configCopy.primary.address = 'n1T3Tg3hLEH58Tmzeqeu1SfycAga1p1W2p';
    const transaction = new Transactions(configCopy, rpcDataTransactionsCopy).handleGeneration(extraNonce);
    expect(transaction[0].slice(0, -5)).toStrictEqual(Buffer.from('0200000025c43660010000000000000000000000000000000000000000000000000000000000000000ffffffff0f5104', 'hex'));
    expect(transaction[1]).toStrictEqual(Buffer.from('00000000021019062a010000001976a914daa52a00b0d89cedd9bea09ba947bff73f8112b488ac0000000000000000266a24aa21a9ede2f61c3f71d1defd3fa999dfa36953755c690689799962b48bebd836974e8cf900000000', 'hex'));
  });
});
